From e8d5bdc84ecfdf6fe5008655215a258bbdf0c521 Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Thu, 03 Feb 2011 08:58:07 -0500
Subject: [PATCH] - Fix IDNA support when IDN/INTL modules are in use (#1487742)
---
program/include/html.php | 102 ++++++++++++++++++++++++++++----------------------
1 files changed, 57 insertions(+), 45 deletions(-)
diff --git a/program/include/html.php b/program/include/html.php
index 527fa9b..ef7314e 100644
--- a/program/include/html.php
+++ b/program/include/html.php
@@ -5,7 +5,7 @@
| program/include/html.php |
| |
| This file is part of the Roundcube Webmail client |
- | Copyright (C) 2005-2010, Roundcube Dev, - Switzerland |
+ | Copyright (C) 2005-2010, The Roundcube Dev Team |
| Licensed under the GNU GPL |
| |
| PURPOSE: |
@@ -39,7 +39,7 @@
/**
* Constructor
*
* @param array Hash array with tag attributes
*/
public function __construct($attrib = array())
{
@@ -63,19 +63,22 @@
/**
* Generic method to create a HTML tag
*
* @param string Tag name
* @param array Tag attributes as key/value pairs
* @param string Optinal Tag content (creates a container tag)
* @param array List with allowed attributes, omit to allow all
* @return string The XHTML tag
*/
public static function tag($tagname, $attrib = array(), $content = null, $allowed_attrib = null)
{
+ if (is_string($attrib))
+ $attrib = array('class' => $attrib);
+
$inline_tags = array('a','span','img');
$suffix = $attrib['nl'] || ($content && $attrib['nl'] !== false && !in_array($tagname, $inline_tags)) ? "\n" : '';
$tagname = self::$lc_tags ? strtolower($tagname) : $tagname;
- if ($content || in_array($tagname, self::$containers)) {
+ if (isset($content) || in_array($tagname, self::$containers)) {
$templ = $attrib['noclose'] ? "<%s%s>%s" : "<%s%s>%s</%s>%s";
unset($attrib['noclose']);
return sprintf($templ, $tagname, self::attrib_string($attrib, $allowed_attrib), $content, $tagname, $suffix);
@@ -88,8 +91,8 @@
/**
* Derrived method for <div> containers
*
- * @param mixed Hash array with tag attributes or string with class name
- * @param string Div content
+ * @param mixed $attr Hash array with tag attributes or string with class name
+ * @param string $cont Div content
* @return string HTML code
* @see html::tag()
*/
@@ -104,8 +107,8 @@
/**
* Derrived method for <p> blocks
*
- * @param mixed Hash array with tag attributes or string with class name
- * @param string Paragraph content
+ * @param mixed $attr Hash array with tag attributes or string with class name
+ * @param string $cont Paragraph content
* @return string HTML code
* @see html::tag()
*/
@@ -120,7 +123,7 @@
/**
* Derrived method to create <img />
*
- * @param mixed Hash array with tag attributes or string with image source (src)
+ * @param mixed $attr Hash array with tag attributes or string with image source (src)
* @return string HTML code
* @see html::tag()
*/
@@ -136,8 +139,8 @@
/**
* Derrived method for link tags
*
- * @param mixed Hash array with tag attributes or string with link location (href)
- * @param string Link content
+ * @param mixed $attr Hash array with tag attributes or string with link location (href)
+ * @param string $cont Link content
* @return string HTML code
* @see html::tag()
*/
@@ -147,14 +150,14 @@
$attr = array('href' => $attr);
}
return self::tag('a', $attr, $cont, array_merge(self::$common_attrib,
- array('href','target','name','onclick','onmouseover','onmouseout','onmousedown','onmouseup')));
+ array('href','target','name','rel','onclick','onmouseover','onmouseout','onmousedown','onmouseup')));
}
/**
* Derrived method for inline span tags
*
- * @param mixed Hash array with tag attributes or string with class name
- * @param string Tag content
+ * @param mixed $attr Hash array with tag attributes or string with class name
+ * @param string $cont Tag content
* @return string HTML code
* @see html::tag()
*/
@@ -169,8 +172,8 @@
/**
* Derrived method for form element labels
*
- * @param mixed Hash array with tag attributes or string with 'for' attrib
- * @param string Tag content
+ * @param mixed $attr Hash array with tag attributes or string with 'for' attrib
+ * @param string $cont Tag content
* @return string HTML code
* @see html::tag()
*/
@@ -185,7 +188,7 @@
/**
* Derrived method to create <iframe></iframe>
*
- * @param mixed Hash array with tag attributes or string with frame source (src)
+ * @param mixed $attr Hash array with tag attributes or string with frame source (src)
* @return string HTML code
* @see html::tag()
*/
@@ -212,8 +215,8 @@
/**
* Create string with attributes
*
* @param array Associative arry with tag attributes
* @param array List of allowed attributes
* @return string Valid attribute string
*/
public static function attrib_string($attrib = array(), $allowed = null)
@@ -270,6 +273,11 @@
'autocomplete','checked','onchange','onclick','disabled','readonly',
'spellcheck','results','maxlength','src');
+ /**
+ * Object constructor
+ *
+ * @param array $attrib Associative array with tag attributes
+ */
public function __construct($attrib = array())
{
if (is_array($attrib)) {
@@ -288,8 +296,8 @@
/**
* Compose input tag
*
* @param string Field value
* @param array Additional attributes to override
* @return string HTML output
*/
public function show($value = null, $attrib = null)
@@ -334,7 +342,7 @@
/**
* Constructor
*
* @param array Named tag attributes
*/
public function __construct($attrib = null)
{
@@ -346,7 +354,7 @@
/**
* Add a hidden field to this instance
*
* @param array Named tag attributes
*/
public function add($attrib)
{
@@ -380,8 +388,8 @@
/**
* Get HTML code for this object
*
* @param string Value of the checked field
* @param array Additional attributes to override
* @return string HTML output
*/
public function show($value = '', $attrib = null)
@@ -410,8 +418,8 @@
/**
* Get HTML code for this object
*
* @param string Value of the checked field
* @param array Additional attributes to override
* @return string HTML output
*/
public function show($value = '', $attrib = null)
@@ -442,8 +450,8 @@
/**
* Get HTML code for this object
*
* @param string Textbox value
* @param array Additional attributes to override
* @return string HTML output
*/
public function show($value = '', $attrib = null)
@@ -496,13 +504,13 @@
protected $tagname = 'select';
protected $options = array();
protected $allowed = array('name','size','tabindex','autocomplete',
- 'multiple','onchange','disabled');
+ 'multiple','onchange','disabled','rel');
/**
* Add a new option to this drop-down
*
- * @param mixed Option name or array with option names
- * @param mixed Option value or array with option values
+ * @param mixed $names Option name or array with option names
+ * @param mixed $values Option value or array with option values
*/
public function add($names, $values = null)
{
@@ -520,8 +528,8 @@
/**
* Get HTML code for this object
*
* @param string Value of the selection option
* @param array Additional attributes to override
* @return string HTML output
*/
public function show($select = array(), $attrib = null)
@@ -562,7 +570,11 @@
private $rowindex = 0;
private $colindex = 0;
-
+ /**
+ * Constructor
+ *
+ * @param array $attrib Named tag attributes
+ */
public function __construct($attrib = array())
{
$this->attrib = array_merge($attrib, array('summary' => '', 'border' => 0));
@@ -571,8 +583,8 @@
/**
* Add a table cell
*
- * @param array Cell attributes
- * @param string Cell content
+ * @param array $attr Cell attributes
+ * @param string $cont Cell content
*/
public function add($attr, $cont)
{
@@ -595,8 +607,8 @@
/**
* Add a table header cell
*
- * @param array Cell attributes
- * @param string Cell content
+ * @param array $attr Cell attributes
+ * @param string $cont Cell content
*/
public function add_header($attr, $cont)
{
@@ -640,7 +652,7 @@
/**
* Jump to next row
*
- * @param array Row attributes
+ * @param array $attr Row attributes
*/
public function add_row($attr = array())
{
@@ -654,7 +666,7 @@
/**
* Set current row attrib
*
- * @param array Row attributes
+ * @param array $attr Row attributes
*/
public function set_row_attribs($attr = array())
{
@@ -667,7 +679,7 @@
/**
* Build HTML output of the table data
*
* @param array Table attributes
* @return string The final table HTML code
*/
public function show($attrib = null)
@@ -39,7 +39,7 @@
* Constructor
*
- * @param array Hash array with tag attributes
+ * @param array $attrib Hash array with tag attributes
*/
public function __construct($attrib = array())
@@ -63,19 +63,22 @@
* Generic method to create a HTML tag
*
- * @param string Tag name
- * @param array Tag attributes as key/value pairs
- * @param string Optinal Tag content (creates a container tag)
- * @param array List with allowed attributes, omit to allow all
+ * @param string $tagname Tag name
+ * @param array $attrib Tag attributes as key/value pairs
+ * @param string $content Optinal Tag content (creates a container tag)
+ * @param array $allowed_attrib List with allowed attributes, omit to allow all
* @return string The XHTML tag
*/
@@ -212,8 +215,8 @@
* Create string with attributes
*
- * @param array Associative arry with tag attributes
- * @param array List of allowed attributes
+ * @param array $attrib Associative arry with tag attributes
+ * @param array $allowed List of allowed attributes
* @return string Valid attribute string
*/
@@ -288,8 +296,8 @@
* Compose input tag
*
- * @param string Field value
- * @param array Additional attributes to override
+ * @param string $value Field value
+ * @param array $attrib Additional attributes to override
* @return string HTML output
*/
@@ -334,7 +342,7 @@
* Constructor
*
- * @param array Named tag attributes
+ * @param array $attrib Named tag attributes
*/
public function __construct($attrib = null)
@@ -346,7 +354,7 @@
* Add a hidden field to this instance
*
- * @param array Named tag attributes
+ * @param array $attrib Named tag attributes
*/
public function add($attrib)
@@ -380,8 +388,8 @@
* Get HTML code for this object
*
- * @param string Value of the checked field
- * @param array Additional attributes to override
+ * @param string $value Value of the checked field
+ * @param array $attrib Additional attributes to override
* @return string HTML output
*/
@@ -410,8 +418,8 @@
* Get HTML code for this object
*
- * @param string Value of the checked field
- * @param array Additional attributes to override
+ * @param string $value Value of the checked field
+ * @param array $attrib Additional attributes to override
* @return string HTML output
*/
@@ -442,8 +450,8 @@
* Get HTML code for this object
*
- * @param string Textbox value
- * @param array Additional attributes to override
+ * @param string $value Textbox value
+ * @param array $attrib Additional attributes to override
* @return string HTML output
*/
@@ -520,8 +528,8 @@
* Get HTML code for this object
*
- * @param string Value of the selection option
- * @param array Additional attributes to override
+ * @param string $select Value of the selection option
+ * @param array $attrib Additional attributes to override
* @return string HTML output
*/
@@ -667,7 +679,7 @@
* Build HTML output of the table data
*
- * @param array Table attributes
+ * @param array $attrib Table attributes
* @return string The final table HTML code
*/
--
Gitblit v1.9.1